@@ -3,7 +3,7 @@ plot.autoKrige = function(x, sp.layout = NULL, ...)
 # This includes the kriging prediction, the kriging results,
 # the experimental variogram and the fitted variogram model
 {
-    
+  askpar = par("ask")
     xx = list(exp_var = x$exp_var, var_model = x$var_model)
     class(xx) = "autofitVariogram"
     vario = plot(xx, plotit = FALSE)
@@ -12,17 +12,22 @@ plot.autoKrige = function(x, sp.layout = NULL, ...)
 #			ylim = ylim, xlab = xlab, ylab = ylab, labels = labels, model = model, 
 #			direction = c(x$dir.hor[1], x$dir.ver[1]), shift = shift, 
 #			mode = "direct", ...)
-
-    pred = automapPlot(x$krige_output,
+    kout = x$krige_output
+    if (inherits(kout, "sf")) {
+      kout = as(kout, "Spatial")
+      gridded(kout) = TRUE
+    }
+    pred = automapPlot(kout,
           zcol = "var1.pred",
           main = "Kriging prediction",
           sp.layout = sp.layout, ...)
 
-    stdev = automapPlot(x$krige_output,
+    stdev = automapPlot(kout,
           zcol = "var1.stdev",
           main = "Kriging standard error",
           sp.layout = sp.layout, ...)
 
+      
       print(pred, position = c(0,.5,.5,1),more=T)
       print(stdev, position = c(.5,.5,1,1),more = T)
       print(vario, position = c(0,0,1,.5)) 
