@@ -1,13 +1,15 @@
 plot.posPredictionInterval = function(x, sp.layout = NULL, justPosition = TRUE, main = "Position prediction interval",...)
 # Plot function for posPredictionInterval
 {
-    upper = automapPlot(x$pos_prediction,
+    pos_prediction = x$pos_prediction
+    if (inherits(pos_prediction, "sf")) pos_prediction = as(pos_prediction, "Spatial")
+    upper = automapPlot(pos_prediction,
                         zcol = "upper",
                         main = "Upper boundary",
                         sp.layout = sp.layout,
                         ...)
 
-    lower = automapPlot(x$pos_prediction,
+    lower = automapPlot(pos_prediction,
                         zcol = "lower",
                         main = "Lower boundary",
                         sp.layout = sp.layout,
@@ -15,8 +17,8 @@ plot.posPredictionInterval = function(x, sp.layout = NULL, justPosition = TRUE,
 
     position2color = list(higher = "red", lower = "blue")
     position2color["not distinguishable"] = "yellow"
-    color = sapply(levels(x$pos_prediction$position), FUN = function(x) position2color[[x]])
-    position = spplot(x$pos_prediction,
+    color = sapply(levels(pos_prediction$position), FUN = function(x) position2color[[x]])
+    position = spplot(pos_prediction,
                         zcol = "position",
                         main = main,
                         col.regions = color,
